# -*- Mode: Python; tab-width: 4 -*-
#
#	$Gaaros: Id$
#	Author: Pavlos Christoforou <pavlos@gaaros.com>
#
# ======================================================================
#
#
#  Disclaimer
#
#
#   Redistribution and use in source and binary forms, with or without
#   modification, are permitted provided that the following conditions
#   are met:
#
#     Redistributions of source code must retain the above copyright
#     notice, this list of conditions and the following disclaimer.
#
#     Redistributions in binary form must reproduce the above copyright
#     notice, this list of conditions and the following disclaimer in the
#     documentation and/or other materials provided with the distribution.
#
#     The name of the author or GAAROS may not be used to endorse or
#     promote products derived from this software without specific prior
#     written permission
#
#
#   THIS SOFTWARE IS PROVIDED BY GAAROS ``AS IS'' AND ANY
#   EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
#   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
#   PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL GAAROS OR HIS
#   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
#   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
#   USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
#   ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
#   OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
#   OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
#   SUCH DAMAGE.
#
########################################################################

__version__='$Revision: 1.1 $'[11:-2]

from Globals import HTML,HTMLFile      
from Globals import MessageDialog 

from zlib import adler32
import styles
#from creosote import spew

import pdflib,elements
from htmltopdf import HTMLParser

import OFS.DTMLDocument
import StructuredText


default_dd_html="""<!--#var standard_html_header-->
<H2><!--#var title_or_id--> <!--#var document_title--></H2>
<P>This is the <!--#var document_id--> Zpdf Document.</P>
<!--#var standard_html_footer-->"""



manage_addZpdfDocumentForm = HTMLFile('zpdfdocumentAddForm', globals())

def manage_addZpdfDocument(self, id, title='ZpdfDocument object',
                  file='', REQUEST=None, submit=None):
    """Add a Zpdf Document object with the contents of file. If
    'file' is empty, default document text is used.
    """
    if type(file) is not type(''): file=file.read()
    if not file: file=default_dd_html
    ob=ZpdfDocument(id, title, file)
    ob.title=title
    id=self._setObject(id, ob)
    if REQUEST is not None:
        try: u=self.DestinationURL()
        except: u=REQUEST['URL1']
        if submit==" Add and Edit ": u="%s/%s" % (u,quote(id))
        REQUEST.RESPONSE.redirect(u+'/manage_main')
    return ''

class ZpdfDocument(OFS.DTMLDocument.DTMLDocument):
    """ZpdfDocument object."""    
        
    meta_type = 'ZpdfDocument' 

    props=[]
    props.append({'id':'input_form', 'type':'string', 'mode': 'w'})
    prop_set=styles.default.items()
    prop_set.sort()
    for key,item in prop_set:
        if type(item)==type(1):
            _tp='int'
        elif type(item)==type(()):
            _tp='tokens'
        else:
            _tp='string'
        props.append({'id':key, 'type': _tp})

    _properties=tuple(props)
    
    def __init__(self, id, title, file): 
        """initialise a new instance of ZpdfDocument"""
        OFS.DTMLDocument.DTMLDocument.__init__.im_func(self,file,__name__=id)
        _st={}
        _st.update(styles.default)
        _st.update(styles.zpdf_doc)
        for key,item in _st.items():
            self._updateProperty(key,item)
        self._updateProperty('input_form','html')
        self.cached_src=''
        self.cached_style=_st

    manage_about = HTMLFile('README', globals())
    manage_elementHelp = HTMLFile('help', globals()) 

    manage_options=({'label':'Edit', 'action':'manage_main'},
                    {'label':'Upload', 'action':'manage_uploadForm'},
                    {'label':'Properties', 'action':'manage_propertiesForm'},
                    {'label':'View', 'action':''},
                    {'label':'Proxy', 'action':'manage_proxyForm'},
                    {'label':'Security', 'action':'manage_access'},
                    {'label':'ElementHelp', 'action':'manage_elementHelp'},
                    {'label':'About', 'action':'manage_about'},
                   )


    __ac_permissions__=( 
        ('Change ZpdfDocuments',   ('manage_edit', 'manage_upload', 'PUT')),
        ('View management screens', ('manage_tabs',
                        'manage_main','manage_about','manage_elementHelp')),
        )


    def __call__(self, client=None, REQUEST={}, RESPONSE=None, **kw):
        """Render the document given a client object, REQUEST mapping,
        Response, and key word arguments."""
        kw['document_id']   =self.id
        kw['document_title']=self.title
        if hasattr(self, 'aq_explicit'): bself=self.aq_explicit
        else: bself=self
        if client is None:
            # Called as subtemplate, so don't need error propigation!
            r=apply(HTML.__call__, (self, bself, REQUEST), kw)
            if RESPONSE is None: return self.to_pdf(r)
            return self.to_pdf(decapitate(r, RESPONSE))
        try:
            r=apply(HTML.__call__, (self, (client, bself), REQUEST), kw)
            if type(r) is not type(''): return self.to_pdf(r)
        except:
            if self.id()=='standard_error_message':
                raise sys.exc_type, sys.exc_value, sys.exc_traceback
            return self.raise_standardErrorMessage(client, REQUEST)
        if RESPONSE is None: return self.to_pdf(r)
        RESPONSE.setHeader('Content-Type','application/pdf')
        return self.to_pdf(r)

    manage_editForm=HTMLFile('documentEdit', globals())
    manage=manage_main=manage_editDocument=manage_editForm
    
    def manage_edit(self,data,title,input_form='html',SUBMIT='Change',
                    dtpref_cols='50',
                    dtpref_rows='20',REQUEST=None):
        """From Zope standard distribution ...
        
        Replaces a Documents contents with Data, Title with Title.

        The SUBMIT parameter is also used to change the size of the editing
        area on the default Document edit screen.  If the value is "Smaller",
        the rows and columns decrease by 5.  If the value is "Bigger", the
        rows and columns increase by 5.  If any other or no value is supplied,
        the data gets checked for DTML errors and is saved.
        """
        self._validateProxy(REQUEST)
        if self._size_changes.has_key(SUBMIT):
            return self._er(data,title,SUBMIT,dtpref_cols,dtpref_rows,REQUEST)

        self.title=title
        self._updateProperty('input_form',input_form)
        if type(data) is not type(''): data=data.read()
        self.munge(data)
        if REQUEST:
            message="Content changed."
            return self.manage_main(self,REQUEST,manage_tabs_message=message)

        

    def to_pdf(self,doc_src):
        '''Convert html to pdf'''
        # First check if there were any modifications
        tmp_st={}
        for key in self.cached_style.keys():
            tmp_st[key]=self.getProperty(key)
        tmp_src=adler32(doc_src)

        if tmp_st==self.cached_style and tmp_src==self.cached_src and hasattr(self,'_v_cached_doc'):
            return self._v_cached_doc

        # convert ot html if in structured text
        if self.getProperty('input_form')=='structured-text':
            doc_src=str(StructuredText.html_with_references(str(doc_src),2))

        out=[]
        p = HTMLParser(out,0)
        p.feed(doc_src)
        p.close()

        doc=pdflib.Document()
        doc.initialize()
        doc.set_style(tmp_st)
        
        lt=elements.HeaderLine()
        lt['position']='T'
        
        lb=elements.HeaderLine()
        lb['position']='B'
        
        htr=elements.Header()
        htr['position']='TR'

        hbr=elements.Header()
        hbr['Header_text']='Zpdf v0.1'
        hbr.add_page_no()
        hbr['position']='BR'

        doc.add_commonElements([lt,lb,hbr,htr])
        doc.add_elements(out)
        doc.format()

        self.cached_style=tmp_st
        self.cached_src=tmp_src
        self._v_cached_doc=doc.to_PDF()

        return self._v_cached_doc

