# -*- Mode: Python; tab-width: 4 -*-
#
#	$Gaaros: Id$
#	Author: Pavlos Christoforou <pavlos@gaaros.com>
#
# ======================================================================
#
#
#  Disclaimer
#
#
#   Redistribution and use in source and binary forms, with or without
#   modification, are permitted provided that the following conditions
#   are met:
#
#     Redistributions of source code must retain the above copyright
#     notice, this list of conditions and the following disclaimer.
#
#     Redistributions in binary form must reproduce the above copyright
#     notice, this list of conditions and the following disclaimer in the
#     documentation and/or other materials provided with the distribution.
#
#     The name of the author or GAAROS may not be used to endorse or
#     promote products derived from this software without specific prior
#     written permission
#
#
#   THIS SOFTWARE IS PROVIDED BY GAAROS ``AS IS'' AND ANY
#   EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
#   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
#   PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL GAAROS OR HIS
#   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
#   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
#   USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
#   ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
#   OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
#   OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
#   SUCH DAMAGE.
#
########################################################################

__version__='$Revision: 1.1 $'[11:-2]

__doc__="""
Style files define the page layout. At this point all dimensions
are absolute.The default style dictionary should be used by all
documents. Modifications can update the default one.

Element description:

    title -- the title of the document that appears in the PDF info
    section

    author -- the author's anme that appears in the info section

    page_width -- the width of the physical page in points (1 inch=72 points)

    page_height -- the height of the physical page in points

    top_margin -- top margin in points (similarly for bottom, right
    and left margins)

    text_area_width -- the width of the availble text area in
    points. Similarly for text_area_height

    font_family -- the font family must be one of the default font
    families that are guaranteed to exist for any pdf
    reader. Currently these are *Courier, Courier-Bold,
    Courier-Oblique, Courier-BoldOblique, Helvetica, Helvetica-Bold,
    Helvetica-Oblique, Helvetica-BoldOblique, Times-Roman, Times-Bold,
    Times-Italic, Times-BoldItalic, Symbol and ZapfDingbats*.

    font_size -- the default font size in points

    word_spacing -- extra spacing to be added to the default pdf word
    spacing

    tw_range -- word spacing shrink and stretch factors. Needed for
    justification. During formatting inter word spacing will be
    changed to enable fitting a loose word or filling up empty space
    at the end of a line. This parameter defines the maximum and
    minimum factor by which the inter-word space can be
    changed. Typesetting sysems like Latex include very sophisticated
    algorithms to achieve pleasing line and paragraph breaks. The
    simple algorithm employed here will give acceptable ragged right
    results as long as the length of individual words is small
    compared with the length of the line (ie small fonts and large
    text_area_width), otherwise proper hyphenation will be required

    indent -- the default paragraph indent in points

    letter_spacing -- additional inter-character spacing on top of the
    default one provided by pdf.
    
    left_offset -- default text offset from the left margin in
    points

    break_widows -- minimum number of widow lines allowed. At least
    this many lines from a paragraph should appear at the end of the
    page or else the whole paragraph will be moved to the following
    page

    break_orphans -- minimum number of orphan lines allowed. At least
    this many lines from a paragraph should appear at the top of a
    page or else the whole paragraph will be moved in the current page

    level -- The initial paragraph level. Mainly needed for section
    numbering reasons

    alignment -- the default alignment, currently ragged-right,
    justified, centered, right

    P_left_offset -- default paragraph offset from left margin in
    points

    P_bottom_dy -- extra vertical space additional to the default
    baseline space that is added at the end of a paragraph. Similarly
    for P_top_dy.

    PRE_font_family -- default family for verbatim text (HTML's PRE tag)

    PRE_left_offset -- default offset from left margin for example text

    PRE_bottom_dy -- see P_bottom_dy

    LI_bottom_dy -- see P_bottom_dy (for lists)

    bullet_char -- default character for bullets

    bullet_font_family -- default bullet family

    bullet_x_offset -- bullet horizontal displacement in points from beginning
    of paragraph
    
    level_offset -- indent in points for sub-lists

    OL_font_family -- default family for ordered lists specifiers

    H_bullet_x_offset -- default horizontal displacement in points of
    section numbers from section text

    H1_left_offset -- default left offset of H1 titles.

    H1_font_family -- default family for H1 titles

    H1_font_size -- default font size in points of H1 titles

    H1_bottom_dy -- extra vertical space additional to the default
    baseline space that is added at the end of an H1 title. Similarly
    for H2_top_dy

    H2_numbering -- indicates whether titles of this level should be
    numbered or not

    Similarly for H2, H3 etc

    HR_thickness -- horizontal line thickness

    HR_width -- width in horizontal lnes in percentage of text_area_width

    HR_bottom_dy -- extra vertical space additional to the default
    baseline space that is added at the bottom of a horizontal
    line. Similarly for HR_top_dy

    Header_section -- indicates which section should appear in the page header

    Header_text -- default header text to appear on all page headers

    Header_top_y -- vertical space in points between top header baseline
    and top margin

    Header_bottom_y -- vertical space in points between bottom header
    baseline and bottom margin

    Header_font_family -- header font family

    Header_font_size -- header font size in points

    Header_line_thickness -- thicknes in points of horizontal line
    seperator between the header and the rest of the page. For no
    header lines set this variable to 0

    Header_line_y_offset -- vertical offset in points from top and
    bottom of text area
    
"""


default={
    'title':'',
    'author':'',
    
    'page_width':612,
    'page_height':792,

    'top_margin':82,
    'bottom_margin':82,
    'left_margin':72,
    'right_margin':72,
    'text_area_width':468, 
    'text_area_height':628,
    
    'font_family':'Times-Roman',
    'font_size':10,

    'word_spacing':0,
    'tw_range':(0.6,1.3),
    'indent':0,
    'letter_spacing':0,
    'left_offset':0,
    'break_widows':4,
    'break_orphans':4,
    'level':0,
    'alignment':'ragged-right',
    
    'P_left_offset':0,
    'P_bottom_dy':8,
    'P_top_dy':0,

    'PRE_font_family':'Courier',
    'PRE_left_offset':0,
    'PRE_bottom_dy':8,
    'PRE_top_dy':0,
    
    'LI_bottom_dy':8,
    'LI_top_dy':0,
    
    'bullet_char':'\236',
    'bullet_font_family':'Symbol',
    'bullet_x_offset':13,
    'level_offset':13,

    'OL_font_family':'Times-Bold',

    'H_bullet_x_offset':35,
    
    'H1_left_offset':0,
    'H1_font_family':'Helvetica-Bold',
    'H1_font_size':22,
    'H1_bottom_dy':21,
    'H1_top_dy':10,
    'H1_numbering':1,

    'H2_left_offset':0,
    'H2_font_family':'Helvetica-Bold',
    'H2_font_size':14,
    'H2_bottom_dy':15,
    'H2_top_dy':5,
    'H2_numbering':1,

    'H3_left_offset':0,
    'H3_font_family':'Helvetica-Bold',
    'H3_font_size':12,
    'H3_bottom_dy':11,
    'H3_top_dy':6,
    'H3_numbering':1,

    'H4_left_offset':0,
    'H4_font_family':'Helvetica-Bold',
    'H4_font_size':10,
    'H4_bottom_dy':10,
    'H4_top_dy':5,

    'H5_left_offset':0,
    'H5_font_family':'Helvetica-Bold',
    'H5_font_size':10,
    'H5_bottom_dy':8,
    'H5_top_dy':3,

    'H6_left_offset':0,
    'H6_font_family':'Helvetica-Bold',
    'H6_font_size':10,
    'H6_bottom_dy':10,
    'H6_top_dy':5,

    'HR_thickness':2,
    'HR_width':'100%',
    'HR_bottom_dy':7,
    'HR_top_dy':3,

    'Header_section':'H2',
    'Header_text':' ',
    'Header_top_y':12,
    'Header_bottom_y':8,
    'Header_font_family':'Helvetica-Bold',
    'Header_font_size':10,
    'Header_line_thickness':2,
    'Header_line_y_offset':7
}

zpdf_doc={
    'font_size':11,
    
    'P_left_offset':40,

    'PRE_left_offset':40,
    
    'H1_numbering':0,
    'H1_left_offset':0,
    'H1_font_size':16,
    'H1_bottom_dy':14,
    'H1_top_dy':10,
    
    'H2_left_offset':20,
    'H3_left_offset':40,
    'H4_left_offset':40,
    'H5_left_offset':40,
    'H6_left_offset':40
    }
